Event Error Messages
====================

====  =============================  =================================
Code  Error Message                  Events
====  =============================  =================================
0     no error                       Stack
203   equipment is moving            ScopeTrack
207   fail to operate                ScopeTrack
251   solve failed                   AutoGoto, PlateSolve
263   stack error, too few stars     Alert, Stack
264   stack error, transform failed  Alert
270   below horizon                  Alert, ScopeTrack
279   no star is detected            AutoFocus
501   mount goto failed              AutoGoto, AutoGotoStep, ScopeGoto
502   mount sync failed              ScopeTrack
514   interrupt                      Exposure
530   star trails                    Alert, Stack
====  =============================  =================================
